@@ -144,6 +144,11 @@ module.exports = generators.Base.extend({
       this.appName = mout.string.pascalCase(this.appName);
       this.appId = this.options.appId || 'com.example.' + this.appName;
       this.appPath = 'app';
+      this.ctrlPath = this.appPath + '/controllers/';
+      this.servicesPath = this.appPath + '/services/';
+      this.modelsPath = this.appPath + '/services/models/';
+      this.directivesPath = this.appPath + '/directives/';
+      this.viewPath = 'template/';
       this.root = process.cwd() + '/' + this.appName;
 
       this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
