@@ -3,7 +3,7 @@ var path = require('path');
 
 var createService = function(self, provider) {
   var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/' + provider + 'AuthService.js'))
-  file = file.replace("{{APP_NAME}}", self.appName);    
+  file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
   self.write(path.join(self.appPath, provider+'Service.js'), file);
 }
 
