@@ -5,7 +5,9 @@ module.exports = {
   greeting: require('./greeting'),
   plugins: require('./plugins'),
   starters: require('./starters'),
-  auth: require('./auth.js')
+  auth: require('./auth.js'),
+  routes: require('./routes.js'),
+  models: require('./models.js')
 };
 
 function mergeCollections(arr1, arr2, prop) {
