@@ -42,9 +42,9 @@ module.exports = {
     for (var i = models.length - 1; i >= 0; i--) {
       var m = models[i];
       var modelFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/model.js'))
-      modelFile = modelFile.replace("{{APP_NAME}}", self.appName);
-      modelFile = modelFile.replace("{{MODEL}}", m);
-      self.write(path.join(self.appPath, m + '.js'), modelFile);
+      modelFile = modelFile.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
+      modelFile = modelFile.replace(new RegExp("{{MODEL}}", 'g'), m);
+      self.write(path.join(self.modelsPath, m + '.js'), modelFile);
     };
     done();
   },
